@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""The code is written using the Keras Sequential API with a tf.GradientTape
+"""The code is written using the Keras Model API with a tf.GradientTape
 training loop. This module implements the minmax game used to train a GAN.
 
 Generative Adversarial Networks (GANs) are one of the most interesting ideas in
@@ -177,10 +177,10 @@ class GAN():
         gan = GAN(generator, discriminator, z_dims=100)
 
         # Define optimizer.
-        gan.compile(lr_gen=1e-4, lr_disc=1e-4)
+        gan.compile()
 
         # Start training process.
-        gan.fit(dataset, EPOCHS, BATCH_SIZE, save_ckpt=5)
+        gan.fit(dataset, ...)
 
         # Export both models.
         gan.export()
@@ -190,27 +190,14 @@ class GAN():
 
 
     Attributes:
-        generator (keras.model): Keras NN to act as the generator.
-        discriminator (keras.model): Keras NN to act as the discriminator.
-        z_dim (int): Dimension of input latent noise variables to generator.
-        generator_optimizer (keras.optimizer): Optimization alg for generator.
-        discriminator_optimizer (keras.optimizer): Optimization alg for disc.
-        init_timestamp (str): Acts as a unique folder identifier.
-        logdir (str): Top level logdir.
-        tensorboard (str): Path to tensorboard summary files.
-        ckpt_dir (str): Path to ckpt files.
-        ckpt_manager (tf.train.CheckpointManager): Deletes old checkpoints.
-        checkpoint (tf.train.Checkpoint): Groups trackable objects, saving and
-            restoring them.
+        generator: keras.model. Keras NN to act as the generator.
+        discriminator: keras.model. Keras NN to act as the discriminator.
+        z_dim: Integer. Dimension of input latent noise variables to generator.
     """
     def __init__(self, generator, discriminator, z_dim=100):
         """Takes two keras.models that take part in the minmax game.
         Both models define the hypothesis set to our learning model.
-
-        Args:
-            generator (keras.model): Keras NN to act as the generator.
-            discriminator (keras.model): Keras NN to act as the discriminator.
-            z_dim (int): Number of input latent noise variables to generator.
+        z_dim defaults to 100.
         """
         self.generator = generator
         self.discriminator = discriminator
@@ -227,16 +214,17 @@ class GAN():
     def compile(self,
                 optimizer="adam",
                 lr_gen=1e-4,
-                lr_disc=1e-4,
+                lr_disc=4e-4,
                 loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model.
 
         Args:
-            optimizer (str, optional): Optimizer. Defaults to "adam".
-            lr_gen (Float, optional): Learning rate generator. Defaults to 1e4.
-            lr_disc (Float, optional): Learning rate discriminator.
-                Defaults to 1e4.
+            optimizer: String. keras.optimizer. Defaults to "adam".
+            lr_gen: Float. Learning rate used by the generator. Defaults to 1e4.
+            lr_disc: Float. Learning rate used by the discriminator.
+                Defaults to 4e4.
+            loss_scaling: Boolean. Used with mixed precision.
         """
         if optimizer == "adadelta":
             self.generator_optimizer = tf.keras.optimizers.Adadelta(lr_gen)
@@ -281,31 +269,37 @@ class GAN():
                                                            max_to_keep=5)
 
     def fit(self,
-            dataset,
-            epochs,
-            batch_size,
-            len_dataset,
+            x=None,
+            batch_size=None,
+            epochs=1,
+            len_dataset=None,
             save_ckpt=5,
             verbose=1,
             max_outputs=2,
             initial_step=0,
             mlflow=False):
-        """Trains both models for n EPOCHS. Saves ckpts every n EPOCHS.
+        """Trains both models for a fixed number of epochs.
         The training loop together with the optimization algorithm define the
         learning algorithm.
 
         Args:
-            dataset (tf.dataset): tf.Dataset with
-                shape(None, width, height, depth).
-            epochs (int): Number of epochs.
-            batch_size (int): Batch length.
-            save_ckpt (int): Save ckpts every n Epochs.
-            verbose (int, optional): Keras Progbar verbose lvl. Defaults to 1.
-            max_outputs (int, optional): Number of images shown in TB.
+            x: Input data. It should be:
+              - A "tf.data" dataset. Should return a tuple of
+                "(targets)".
+            batch_size: Integer.
+                Number of samples per gradient update, only used to build a
+                keras progressbar. Datasets should generate batches.
+            epochs: Integer. Number of epochs to train the model. An epoch is an
+                iteration over the entire "x" and "y" data provided.
+            save_ckpt: Integer. Save ckpts every n Epochs.
+            verbose: 0, 1, or 2. Verbosity mode.
+                0 = silent, 1 = progress bar, 2 = one line per epoch". Defaults
+                to 1.
+            max_outputs: Integer.  Number of images shown in TB per step.
                 Defaults to 2.
             initial_step (int): Step at which to start training. Useful for
                 resuming a previous run.
-
+            mlflow: Boolean. Triggers mlflow tracking.
 
         Raises:
             ModelNotCompiledError: Raise if model is not compiled.
@@ -328,10 +322,10 @@ class GAN():
         for epoch in range(epochs):
             step_float = 0
             start = time.time()
-            for target_images in dataset:
+            for target_images in x:
                 imgs = self.train_step(target_images, batch_size, step,
                                        file_writer)
-                # TODO Workaround. summary image & gpu usage
+                # Workaround. summary image & gpu usage
                 with file_writer.as_default():  # pylint: disable=not-context-manager
                     tf.summary.image("target", imgs[0], step=step)
                     tf.summary.image("fake_target", imgs[1], step=step)
