@@ -29,6 +29,7 @@ def create_dataset(tfrecords,
                    keys,
                    encoding=True,
                    one_hot_labels=False,
+                   metadata=False,
                    prefetching=True,
                    cache=True):
     """Creates an optimized tf.data.Dataset object from a tfrecords file.
@@ -52,7 +53,7 @@ def create_dataset(tfrecords,
     if encoding:
         parsed_dataset = raw_dataset.map(
             lambda example: _parse_tfrecords_encoded(
-                example, height, width, depth, keys, one_hot_labels),
+                example, height, width, depth, keys, one_hot_labels, metadata),
             num_parallel_calls=tf.data.experimental.AUTOTUNE)
     else:
         parsed_dataset = raw_dataset.map(
@@ -73,7 +74,7 @@ def create_dataset(tfrecords,
 
 
 def _parse_tfrecords_encoded(example, height, width, depth, keys,
-                             one_hot_labels):
+                             one_hot_labels, metadata):
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
@@ -97,7 +98,11 @@ def _parse_tfrecords_encoded(example, height, width, depth, keys,
         label = tf.argmax(example[keys[1]], axis=0)
     else:
         label = example[keys[1]]
-    return img_source, label, img_filename
+
+    if metadata:
+        return img_source, label, img_filename
+    else:
+        return img_source, label
 
 
 def _parse_tfrecords_raw(example, height, width, depth, keys):
