@@ -14,3 +14,5 @@
 # =============================================================================
 """Utils API"""
 from dnnlab.utils import gpu
+from dnnlab.utils import performance
+from dnnlab.utils import coco_map
